from ten99policy.api_resources.abstract import CreateableAPIResource
from ten99policy.api_resources.abstract import ListableAPIResource


class InsuranceApplicationSessions(
    CreateableAPIResource,
    ListableAPIResource,
):
    OBJECT_NAME = "apply/sessions"



# File generated from our OpenAPI spec
from __future__ import absolute_import, division, print_function

# flake8: noqa

from ten99policy.api_resources.error_object import ErrorObject
from ten99policy.api_resources.list_object import ListObject

from ten99policy.api_resources.contractors import Contractors
from ten99policy.api_resources.entities import Entities
from ten99policy.api_resources.jobs import Jobs
from ten99policy.api_resources.policies import Policies
from ten99policy.api_resources.quotes import Quotes
from ten99policy.api_resources.invoices import Invoices
from ten99policy.api_resources.insurance_application_sessions import InsuranceApplicationSessions
from ten99policy.api_resources.events import Events
from ten99policy.api_resources.assignments import Assignments



import ten99policy
ten99policy.api_key = "t9sk_live_db68a311-e4b4-4ee8-b2d6-238bc97d83ed"

# You can configure the environment for 1099Policy API (sandbox|production)
# ten99policy.environment = 'sandbox'


# -----------------------------------------------------------------------------------*/
# Fetching the list of contractors
#-----------------------------------------------------------------------------------*/

# resource = ten99policy.Contractors.list(
#     email='harold@gmail.com',
# )

resource = ten99policy.Contractors.modify('cn_xW5Bu6UPWu',
    email='john.doe@gmail.com',
    first_name="George"
)


print(resource)



import ten99policy


class TestCustomer(object):
    def test_is_listable(self):
        # resources = ten99policy.Contractors.list()
        assert isinstance([], list)

        # resources = ten99policy.Customer.list()
        # request_mock.assert_requested("get", "/v1/customers")
        # assert isinstance(resources.data, list)
        # assert isinstance(resources.data[0], ten99policy.Customer)



from __future__ import absolute_import, division, print_function

# Configuration variables

client_id = None
api_base = "http://localhost:5000"
api_key = 't9sk_test_f189230e-1175-40cc-b71f-30022fb1005b'
api_version = None
verify_ssl_certs = False
proxy = None
default_http_client = None
max_network_retries = 0
environment = 'sandbox'

# Set to either 'debug' or 'info', controls console logging
log = 'debug'

# API resources
from ten99policy.api_resources import *  # noqa



from __future__ import absolute_import, division, print_function

from ten99policy import util
from ten99policy.api_resources.abstract.api_resource import APIResource
from ten99policy.six.moves.urllib.parse import quote_plus


class UpdateableAPIResource(APIResource):
    @classmethod
    def modify(cls, sid, **params):
        url = "%s/%s" % (cls.class_url(), quote_plus(util.utf8(sid)))
        return cls._static_request("put", url, **params)

    def save(self, idempotency_key=None):
        updated_params = self.serialize(None)
        headers = util.populate_headers(idempotency_key)

        if updated_params:
            self.refresh_from(
                self.request(
                    "put", self.instance_url(), updated_params, headers
                )
            )
        else:
            util.logger.debug("Trying to save already saved object %r", self)
        return self



from __future__ import absolute_import, division, print_function

from ten99policy.api_resources.abstract.api_resource import APIResource
from ten99policy import api_requestor, util


class CreateableAPIResource(APIResource):
    @classmethod
    def create(
        cls,
        api_key=None,
        idempotency_key=None,
        ten99policy_version=None,
        ten99policy_environment=None,
        **params
    ):
        requestor = api_requestor.APIRequestor(
            api_key, api_version=ten99policy_version, environment=ten99policy_environment
        )
        url = cls.class_url()
        headers = util.populate_headers(idempotency_key)
        response, api_key = requestor.request("post", url, params, headers)

        return util.convert_to_ten99policy_object(
            response, api_key, ten99policy_version, ten99policy_environment
        )



import os
from codecs import open
from setuptools import setup, find_packages

here = os.path.abspath(os.path.dirname(__file__))

os.chdir(here)

version_contents = {}
with open(os.path.join(here, "ten99policy", "version.py"), encoding="utf-8") as f:
    exec(f.read(), version_contents)

setup(
    name="ten99policy",
    version=version_contents["VERSION"],
    description="Python bindings for the ten99policy API",
    long_description_content_type="text/x-rst",
    author="Ray Ventura",
    author_email="support@1099policy.com",
    url="https://github.com/1099policy/1099policy-client-python",
    license="MIT",
    keywords="ten99policy api insurance",
    packages=find_packages(exclude=["tests", "tests.*"]),
    zip_safe=False,
    install_requires=[
        'requests >= 2.20; python_version >= "3.0"',
        'requests[security] >= 2.20; python_version < "3.0"',
    ],
    python_requires=">=2.7, !=3.0.*, !=3.1.*, !=3.2.*, !=3.3.*",
    project_urls={
        "Bug Tracker": "https://github.com/1099policy/1099policy-client-python/issues",
        "Documentation": "https://1099policy.com/docs/api/?lang=python",
        "Source Code": "https://github.com/1099policy/1099policy-client-python",
    },
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Programming Language :: Python :: 2",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: Implementation :: PyPy",
        "Topic :: Software Development :: Libraries :: Python Modules",
    ],
)
